@@ -16,7 +16,7 @@ use Log::Log4perl::Appender;
 
 use constant _INTERNAL_DEBUG => 1;
 
-our $VERSION = '1.06';
+our $VERSION = '1.08';
 
    # set this to '1' if you're using a wrapper
    # around Log::Log4perl
@@ -1134,8 +1134,7 @@ are located in:
     # ...
 
     package main;
-    Log::Log4perl->init("mylogdefs.conf") or 
-        die "Whoa, cannot read mylogdefs.conf!";
+    Log::Log4perl->init("mylogdefs.conf");
 
         # => "LOG> Creating a new Snickers bar"
     my $first = Candy::Snickers->new();
@@ -2499,11 +2498,11 @@ our
     Kevin Goess <cpan@goess.org>
 
     Contributors (in alphabetical order):
-    Hutton Davidson, Chris R. Donnelly, Matisse Enzer, Hugh Esco,
-    James FitzGibbon, Carl Franks, Dennis Gregorovic, Paul
-    Harrington, David Hull, Robert Jacobson, Jeff Macdonald, Markus
-    Peter, Brett Rann, Erik Selberg, Aaron Straup Cope, Lars Thegler,
-    David Viner, Mac Yang.
+    Ateeq Altaf, Jeremy Bopp, Hutton Davidson, Chris R. Donnelly,
+    Matisse Enzer, Hugh Esco, James FitzGibbon, Carl Franks, Dennis
+    Gregorovic, Paul Harrington, David Hull, Robert Jacobson, Jeff
+    Macdonald, Markus Peter, Brett Rann, Erik Selberg, Aaron Straup
+    Cope, Lars Thegler, David Viner, Mac Yang.
 
 =head1 COPYRIGHT AND LICENSE
 
